#include "pmu-events/pmu-events.h"
static const struct pmu_event pme_cf_z196[] = {
{
	.name = "cpu_cycles",
	.event = "event=0",
	.desc = "Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "instructions",
	.event = "event=0x1",
	.desc = "Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_dir_writes",
	.event = "event=0x2",
	.desc = "Level-1 I-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 instruction-cache or unified-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_penalty_cycles",
	.event = "event=0x3",
	.desc = "Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_dir_writes",
	.event = "event=0x4",
	.desc = "Level-1 D-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 data-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_penalty_cycles",
	.event = "event=0x5",
	.desc = "Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 data cache",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_cpu_cycles",
	.event = "event=0x20",
	.desc = "Problem-State Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_instructions",
	.event = "event=0x21",
	.desc = "Problem-State Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU while in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1i_dir_writes",
	.event = "event=0x22",
	.desc = "Problem-State Level-1 I-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1i_penalty_cycles",
	.event = "event=0x23",
	.desc = "Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1d_dir_writes",
	.event = "event=0x24",
	.desc = "Problem-State Level-1 D-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1d_penalty_cycles",
	.event = "event=0x25",
	.desc = "Problem-State Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "prng_functions",
	.event = "event=0x40",
	.desc = "PRNG Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_cycles",
	.event = "event=0x41",
	.desc = "PRNG Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_functions",
	.event = "event=0x42",
	.desc = "PRNG Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_cycles",
	.event = "event=0x43",
	.desc = "PRNG Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_functions",
	.event = "event=0x44",
	.desc = "SHA Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_cycles",
	.event = "event=0x45",
	.desc = "SHA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_functions",
	.event = "event=0x46",
	.desc = "SHA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_cycles",
	.event = "event=0x47",
	.desc = "SHA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_functions",
	.event = "event=0x48",
	.desc = "DEA Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_cycles",
	.event = "event=0x49",
	.desc = "DEA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_functions",
	.event = "event=0x4a",
	.desc = "DEA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_cycles",
	.event = "event=0x4b",
	.desc = "DEA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_functions",
	.event = "event=0x4c",
	.desc = "AES Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_cycles",
	.event = "event=0x4d",
	.desc = "AES Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_functions",
	.event = "event=0x4e",
	.desc = "AES Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_cycles",
	.event = "event=0x4f",
	.desc = "AES Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_l2_sourced_writes",
	.event = "event=0x80",
	.desc = "L1D L2 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from the Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_l2_sourced_writes",
	.event = "event=0x81",
	.desc = "L1I L2 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from the Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_misses",
	.event = "event=0x82",
	.desc = "DTLB1 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "itlb1_misses",
	.event = "event=0x83",
	.desc = "ITLB1 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Level-1 Instruction TLB miss in progress. Incremented by one for every cycle a ITLB1 miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "l2c_stores_sent",
	.event = "event=0x85",
	.desc = "L2C Stores Sent. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Incremented by one for every store sent to Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offbook_l3_sourced_writes",
	.event = "event=0x86",
	.desc = "L1D Off-Book L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Book Level-3 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onbook_l4_sourced_writes",
	.event = "event=0x87",
	.desc = "L1D On-Book L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an On Book Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onbook_l4_sourced_writes",
	.event = "event=0x88",
	.desc = "L1I On-Book L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an On Book Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_ro_excl_writes",
	.event = "event=0x89",
	.desc = "L1D Read-only Exclusive Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offbook_l4_sourced_writes",
	.event = "event=0x8a",
	.desc = "L1D Off-Book L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Book Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offbook_l4_sourced_writes",
	.event = "event=0x8b",
	.desc = "L1I Off-Book L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Book Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_hpage_writes",
	.event = "event=0x8c",
	.desc = "DTLB1 One-Megabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_lmem_sourced_writes",
	.event = "event=0x8d",
	.desc = "L1D Local Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_lmem_sourced_writes",
	.event = "event=0x8e",
	.desc = "L1I Local Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction Cache where the installed cache line was sourced from memory that is attached to the same book as the Instruction cache (Local Memory)",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offbook_l3_sourced_writes",
	.event = "event=0x8f",
	.desc = "L1I Off-Book L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Book Level-3 cache",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_writes",
	.event = "event=0x90",
	.desc = "DTLB1 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)",
	.pmu = "cpum_cf",
},
{
	.name = "itlb1_writes",
	.event = "event=0x91",
	.desc = "ITLB1 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_pte_writes",
	.event = "event=0x92",
	.desc = "TLB2 PTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Page Table Entry arrays",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_crste_hpage_writes",
	.event = "event=0x93",
	.desc = "TLB2 CRSTE One-Megabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_crste_writes",
	.event = "event=0x94",
	.desc = "TLB2 CRSTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_l3_sourced_writes",
	.event = "event=0x96",
	.desc = "L1D On-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an On Chip Level-3 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offchip_l3_sourced_writes",
	.event = "event=0x98",
	.desc = "L1D Off-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_l3_sourced_writes",
	.event = "event=0x99",
	.desc = "L1I On-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an On Chip Level-3 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offchip_l3_sourced_writes",
	.event = "event=0x9b",
	.desc = "L1I Off-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache",
	.pmu = "cpum_cf",
},
{
	.name = 0,
	.event = 0,
	.desc = 0,
},
};
static const struct pmu_event pme_cf_zec12[] = {
{
	.name = "cpu_cycles",
	.event = "event=0",
	.desc = "Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "instructions",
	.event = "event=0x1",
	.desc = "Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_dir_writes",
	.event = "event=0x2",
	.desc = "Level-1 I-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 instruction-cache or unified-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_penalty_cycles",
	.event = "event=0x3",
	.desc = "Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_dir_writes",
	.event = "event=0x4",
	.desc = "Level-1 D-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 data-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_penalty_cycles",
	.event = "event=0x5",
	.desc = "Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 data cache",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_cpu_cycles",
	.event = "event=0x20",
	.desc = "Problem-State Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_instructions",
	.event = "event=0x21",
	.desc = "Problem-State Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU while in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1i_dir_writes",
	.event = "event=0x22",
	.desc = "Problem-State Level-1 I-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1i_penalty_cycles",
	.event = "event=0x23",
	.desc = "Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1d_dir_writes",
	.event = "event=0x24",
	.desc = "Problem-State Level-1 D-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1d_penalty_cycles",
	.event = "event=0x25",
	.desc = "Problem-State Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.desc = "Transaction count",
	.topic = "transaction",
	.metric_expr = "TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL",
	.metric_name = "transaction",
},
{
	.name = "prng_functions",
	.event = "event=0x40",
	.desc = "PRNG Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_cycles",
	.event = "event=0x41",
	.desc = "PRNG Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_functions",
	.event = "event=0x42",
	.desc = "PRNG Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_cycles",
	.event = "event=0x43",
	.desc = "PRNG Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_functions",
	.event = "event=0x44",
	.desc = "SHA Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_cycles",
	.event = "event=0x45",
	.desc = "SHA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_functions",
	.event = "event=0x46",
	.desc = "SHA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_cycles",
	.event = "event=0x47",
	.desc = "SHA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_functions",
	.event = "event=0x48",
	.desc = "DEA Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_cycles",
	.event = "event=0x49",
	.desc = "DEA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_functions",
	.event = "event=0x4a",
	.desc = "DEA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_cycles",
	.event = "event=0x4b",
	.desc = "DEA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_functions",
	.event = "event=0x4c",
	.desc = "AES Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_cycles",
	.event = "event=0x4d",
	.desc = "AES Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_functions",
	.event = "event=0x4e",
	.desc = "AES Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_cycles",
	.event = "event=0x4f",
	.desc = "AES Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_misses",
	.event = "event=0x80",
	.desc = "DTLB1 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "itlb1_misses",
	.event = "event=0x81",
	.desc = "ITLB1 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Level-1 Instruction TLB miss in progress. Incremented by one for every cycle a ITLB1 miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_l2i_sourced_writes",
	.event = "event=0x82",
	.desc = "L1D L2I Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Instruction cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_l2i_sourced_writes",
	.event = "event=0x83",
	.desc = "L1I L2I Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_l2d_sourced_writes",
	.event = "event=0x84",
	.desc = "L1D L2D Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_writes",
	.event = "event=0x85",
	.desc = "DTLB1 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_lmem_sourced_writes",
	.event = "event=0x87",
	.desc = "L1D Local Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_lmem_sourced_writes",
	.event = "event=0x89",
	.desc = "L1I Local Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache where the installed cache line was sourced from memory that is attached to the same book as the Instruction cache (Local Memory)",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_ro_excl_writes",
	.event = "event=0x8a",
	.desc = "L1D Read-only Exclusive Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_hpage_writes",
	.event = "event=0x8b",
	.desc = "DTLB1 One-Megabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page",
	.pmu = "cpum_cf",
},
{
	.name = "itlb1_writes",
	.event = "event=0x8c",
	.desc = "ITLB1 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_pte_writes",
	.event = "event=0x8d",
	.desc = "TLB2 PTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Page Table Entry arrays",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_crste_hpage_writes",
	.event = "event=0x8e",
	.desc = "TLB2 CRSTE One-Megabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_crste_writes",
	.event = "event=0x8f",
	.desc = "TLB2 CRSTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_l3_sourced_writes",
	.event = "event=0x90",
	.desc = "L1D On-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On Chip Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offchip_l3_sourced_writes",
	.event = "event=0x91",
	.desc = "L1D Off-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offbook_l3_sourced_writes",
	.event = "event=0x92",
	.desc = "L1D Off-Book L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onbook_l4_sourced_writes",
	.event = "event=0x93",
	.desc = "L1D On-Book L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On Book Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offbook_l4_sourced_writes",
	.event = "event=0x94",
	.desc = "L1D Off-Book L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "tx_nc_tend",
	.event = "event=0x95",
	.desc = "Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TEND instruction has completed in a nonconstrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_l3_sourced_writes_iv",
	.event = "event=0x96",
	.desc = "L1D On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from a On Chip Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offchip_l3_sourced_writes_iv",
	.event = "event=0x97",
	.desc = "L1D Off-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offbook_l3_sourced_writes_iv",
	.event = "event=0x98",
	.desc = "L1D Off-Book L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_l3_sourced_writes",
	.event = "event=0x99",
	.desc = "L1I On-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offchip_l3_sourced_writes",
	.event = "event=0x9a",
	.desc = "L1I Off-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offbook_l3_sourced_writes",
	.event = "event=0x9b",
	.desc = "L1I Off-Book L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onbook_l4_sourced_writes",
	.event = "event=0x9c",
	.desc = "L1I On-Book L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Book Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offbook_l4_sourced_writes",
	.event = "event=0x9d",
	.desc = "L1I Off-Book L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tend",
	.event = "event=0x9e",
	.desc = "Completed TEND instructions in constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TEND instruction has completed in a constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_l3_sourced_writes_iv",
	.event = "event=0x9f",
	.desc = "L1I On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offchip_l3_sourced_writes_iv",
	.event = "event=0xa0",
	.desc = "L1I Off-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offbook_l3_sourced_writes_iv",
	.event = "event=0xa1",
	.desc = "L1I Off-Book L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "tx_nc_tabort",
	.event = "event=0xb1",
	.desc = "Aborted transactions in non-constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a nonconstrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tabort_no_special",
	.event = "event=0xb2",
	.desc = "Aborted transactions in constrained TX mode not using special completion logic. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tabort_special",
	.event = "event=0xb3",
	.desc = "Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete",
	.pmu = "cpum_cf",
},
{
	.name = 0,
	.event = 0,
	.desc = 0,
},
};
static const struct pmu_event pme_cf_z10[] = {
{
	.name = "cpu_cycles",
	.event = "event=0",
	.desc = "Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "instructions",
	.event = "event=0x1",
	.desc = "Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_dir_writes",
	.event = "event=0x2",
	.desc = "Level-1 I-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 instruction-cache or unified-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_penalty_cycles",
	.event = "event=0x3",
	.desc = "Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_dir_writes",
	.event = "event=0x4",
	.desc = "Level-1 D-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 data-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_penalty_cycles",
	.event = "event=0x5",
	.desc = "Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 data cache",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_cpu_cycles",
	.event = "event=0x20",
	.desc = "Problem-State Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_instructions",
	.event = "event=0x21",
	.desc = "Problem-State Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU while in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1i_dir_writes",
	.event = "event=0x22",
	.desc = "Problem-State Level-1 I-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1i_penalty_cycles",
	.event = "event=0x23",
	.desc = "Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1d_dir_writes",
	.event = "event=0x24",
	.desc = "Problem-State Level-1 D-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1d_penalty_cycles",
	.event = "event=0x25",
	.desc = "Problem-State Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "prng_functions",
	.event = "event=0x40",
	.desc = "PRNG Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_cycles",
	.event = "event=0x41",
	.desc = "PRNG Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_functions",
	.event = "event=0x42",
	.desc = "PRNG Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_cycles",
	.event = "event=0x43",
	.desc = "PRNG Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_functions",
	.event = "event=0x44",
	.desc = "SHA Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_cycles",
	.event = "event=0x45",
	.desc = "SHA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_functions",
	.event = "event=0x46",
	.desc = "SHA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_cycles",
	.event = "event=0x47",
	.desc = "SHA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_functions",
	.event = "event=0x48",
	.desc = "DEA Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_cycles",
	.event = "event=0x49",
	.desc = "DEA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_functions",
	.event = "event=0x4a",
	.desc = "DEA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_cycles",
	.event = "event=0x4b",
	.desc = "DEA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_functions",
	.event = "event=0x4c",
	.desc = "AES Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_cycles",
	.event = "event=0x4d",
	.desc = "AES Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_functions",
	.event = "event=0x4e",
	.desc = "AES Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_cycles",
	.event = "event=0x4f",
	.desc = "AES Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_l2_sourced_writes",
	.event = "event=0x80",
	.desc = "L1I L2 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from the Level-2 (L1.5) cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_l2_sourced_writes",
	.event = "event=0x81",
	.desc = "L1D L2 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from the Level-2 (L1.5) cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_l3_local_writes",
	.event = "event=0x82",
	.desc = "L1I L3 Local Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction Cache directory where the installed cache line was sourced from the Level-3 cache that is on the same book as the Instruction cache (Local L2 cache)",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_l3_local_writes",
	.event = "event=0x83",
	.desc = "L1D L3 Local Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache directory where the installed cache line was source from the Level-3 cache that is on the same book as the Data cache (Local L2 cache)",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_l3_remote_writes",
	.event = "event=0x84",
	.desc = "L1I L3 Remote Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction Cache directory where the installed cache line was sourced from a Level-3 cache that is not on the same book as the Instruction cache (Remote L2 cache)",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_l3_remote_writes",
	.event = "event=0x85",
	.desc = "L1D L3 Remote Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from a Level-3 cache that is not on the same book as the Data cache (Remote L2 cache)",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_lmem_sourced_writes",
	.event = "event=0x86",
	.desc = "L1D Local Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_lmem_sourced_writes",
	.event = "event=0x87",
	.desc = "L1I Local Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction Cache where the installed cache line was sourced from memory that is attached to the s ame book as the Instruction cache (Local Memory)",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_ro_excl_writes",
	.event = "event=0x88",
	.desc = "L1D Read-only Exclusive Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_cacheline_invalidates",
	.event = "event=0x89",
	.desc = "L1I Cacheline Invalidates. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A cache line in the Level-1 Instruction Cache has been invalidated by a store on the same CPU as the Level-1 Instruction Cache",
	.pmu = "cpum_cf",
},
{
	.name = "itlb1_writes",
	.event = "event=0x8a",
	.desc = "ITLB1 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written into the Level-1 Instruction Translation Lookaside Buffer (ITLB1)",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_writes",
	.event = "event=0x8b",
	.desc = "DTLB1 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_pte_writes",
	.event = "event=0x8c",
	.desc = "TLB2 PTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Page Table Entry arrays",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_crste_writes",
	.event = "event=0x8d",
	.desc = "TLB2 CRSTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_crste_hpage_writes",
	.event = "event=0x8e",
	.desc = "TLB2 CRSTE One-Megabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation",
	.pmu = "cpum_cf",
},
{
	.name = "itlb1_misses",
	.event = "event=0x91",
	.desc = "ITLB1 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Level-1 Instruction TLB miss in progress. Incremented by one for every cycle an ITLB1 miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_misses",
	.event = "event=0x92",
	.desc = "DTLB1 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Level-1 Data TLB miss in progress. Incremented by one for every cycle an DTLB1 miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "l2c_stores_sent",
	.event = "event=0x93",
	.desc = "L2C Stores Sent. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Incremented by one for every store sent to Level-2 (L1.5) cache",
	.pmu = "cpum_cf",
},
{
	.name = 0,
	.event = 0,
	.desc = 0,
},
};
static const struct pmu_event pme_cf_z13[] = {
{
	.name = "cpu_cycles",
	.event = "event=0",
	.desc = "Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "instructions",
	.event = "event=0x1",
	.desc = "Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_dir_writes",
	.event = "event=0x2",
	.desc = "Level-1 I-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 instruction-cache or unified-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_penalty_cycles",
	.event = "event=0x3",
	.desc = "Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_dir_writes",
	.event = "event=0x4",
	.desc = "Level-1 D-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 data-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_penalty_cycles",
	.event = "event=0x5",
	.desc = "Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 data cache",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_cpu_cycles",
	.event = "event=0x20",
	.desc = "Problem-State Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_instructions",
	.event = "event=0x21",
	.desc = "Problem-State Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU while in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1i_dir_writes",
	.event = "event=0x22",
	.desc = "Problem-State Level-1 I-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1i_penalty_cycles",
	.event = "event=0x23",
	.desc = "Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1d_dir_writes",
	.event = "event=0x24",
	.desc = "Problem-State Level-1 D-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_l1d_penalty_cycles",
	.event = "event=0x25",
	.desc = "Problem-State Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state",
	.pmu = "cpum_cf",
},
{
	.desc = "Transaction count",
	.topic = "transaction",
	.metric_expr = "TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL",
	.metric_name = "transaction",
},
{
	.name = "prng_functions",
	.event = "event=0x40",
	.desc = "PRNG Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_cycles",
	.event = "event=0x41",
	.desc = "PRNG Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_functions",
	.event = "event=0x42",
	.desc = "PRNG Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_cycles",
	.event = "event=0x43",
	.desc = "PRNG Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_functions",
	.event = "event=0x44",
	.desc = "SHA Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_cycles",
	.event = "event=0x45",
	.desc = "SHA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_functions",
	.event = "event=0x46",
	.desc = "SHA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_cycles",
	.event = "event=0x47",
	.desc = "SHA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_functions",
	.event = "event=0x48",
	.desc = "DEA Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_cycles",
	.event = "event=0x49",
	.desc = "DEA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_functions",
	.event = "event=0x4a",
	.desc = "DEA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_cycles",
	.event = "event=0x4b",
	.desc = "DEA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_functions",
	.event = "event=0x4c",
	.desc = "AES Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_cycles",
	.event = "event=0x4d",
	.desc = "AES Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_functions",
	.event = "event=0x4e",
	.desc = "AES Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_cycles",
	.event = "event=0x4f",
	.desc = "AES Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_ro_excl_writes",
	.event = "event=0x80",
	.desc = "L1D Read-only Exclusive Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_writes",
	.event = "event=0x81",
	.desc = "DTLB1 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_misses",
	.event = "event=0x82",
	.desc = "DTLB1 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_hpage_writes",
	.event = "event=0x83",
	.desc = "DTLB1 One-Megabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb1_gpage_writes",
	.event = "event=0x84",
	.desc = "DTLB1 Two-Gigabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a two-gigabyte page",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_l2d_sourced_writes",
	.event = "event=0x85",
	.desc = "L1D L2D Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache",
	.pmu = "cpum_cf",
},
{
	.name = "itlb1_writes",
	.event = "event=0x86",
	.desc = "ITLB1 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)",
	.pmu = "cpum_cf",
},
{
	.name = "itlb1_misses",
	.event = "event=0x87",
	.desc = "ITLB1 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Level-1 Instruction TLB miss in progress. Incremented by one for every cycle an ITLB1 miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_l2i_sourced_writes",
	.event = "event=0x88",
	.desc = "L1I L2I Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_pte_writes",
	.event = "event=0x89",
	.desc = "TLB2 PTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Page Table Entry arrays",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_crste_hpage_writes",
	.event = "event=0x8a",
	.desc = "TLB2 CRSTE One-Megabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Combined Region Segment Table Entry arrays for a one-megabyte large page translation",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_crste_writes",
	.event = "event=0x8b",
	.desc = "TLB2 CRSTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written to the Level-2 TLB Combined Region Segment Table Entry arrays",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tend",
	.event = "event=0x8c",
	.desc = "Completed TEND instructions in constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TEND instruction has completed in a constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "tx_nc_tend",
	.event = "event=0x8d",
	.desc = "Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TEND instruction has completed in a non-constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "l1c_tlb1_misses",
	.event = "event=0x8f",
	.desc = "L1C TLB1 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Increments by one for any cycle where a Level-1 cache or Level-1 TLB miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_l3_sourced_writes",
	.event = "event=0x90",
	.desc = "L1D On-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_l3_sourced_writes_iv",
	.event = "event=0x91",
	.desc = "L1D On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onnode_l4_sourced_writes",
	.event = "event=0x92",
	.desc = "L1D On-Node L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onnode_l3_sourced_writes_iv",
	.event = "event=0x93",
	.desc = "L1D On-Node L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onnode_l3_sourced_writes",
	.event = "event=0x94",
	.desc = "L1D On-Node L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_ondrawer_l4_sourced_writes",
	.event = "event=0x95",
	.desc = "L1D On-Drawer L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_ondrawer_l3_sourced_writes_iv",
	.event = "event=0x96",
	.desc = "L1D On-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_ondrawer_l3_sourced_writes",
	.event = "event=0x97",
	.desc = "L1D On-Drawer L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_scol_l4_sourced_writes",
	.event = "event=0x98",
	.desc = "L1D Off-Drawer Same-Column L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_scol_l3_sourced_writes_iv",
	.event = "event=0x99",
	.desc = "L1D Off-Drawer Same-Column L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_scol_l3_sourced_writes",
	.event = "event=0x9a",
	.desc = "L1D Off-Drawer Same-Column L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_fcol_l4_sourced_writes",
	.event = "event=0x9b",
	.desc = "L1D Off-Drawer Far-Column L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_fcol_l3_sourced_writes_iv",
	.event = "event=0x9c",
	.desc = "L1D Off-Drawer Far-Column L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_fcol_l3_sourced_writes",
	.event = "event=0x9d",
	.desc = "L1D Off-Drawer Far-Column L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onnode_mem_sourced_writes",
	.event = "event=0x9e",
	.desc = "L1D On-Node Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Node memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_ondrawer_mem_sourced_writes",
	.event = "event=0x9f",
	.desc = "L1D On-Drawer Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_mem_sourced_writes",
	.event = "event=0xa0",
	.desc = "L1D Off-Drawer Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_mem_sourced_writes",
	.event = "event=0xa1",
	.desc = "L1D On-Chip Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_l3_sourced_writes",
	.event = "event=0xa2",
	.desc = "L1I On-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_l3_sourced_writes_iv",
	.event = "event=0xa3",
	.desc = "L1I On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onnode_l4_sourced_writes",
	.event = "event=0xa4",
	.desc = "L1I On-Chip L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onnode_l3_sourced_writes_iv",
	.event = "event=0xa5",
	.desc = "L1I On-Node L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onnode_l3_sourced_writes",
	.event = "event=0xa6",
	.desc = "L1I On-Node L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_ondrawer_l4_sourced_writes",
	.event = "event=0xa7",
	.desc = "L1I On-Drawer L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_ondrawer_l3_sourced_writes_iv",
	.event = "event=0xa8",
	.desc = "L1I On-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_ondrawer_l3_sourced_writes",
	.event = "event=0xa9",
	.desc = "L1I On-Drawer L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_scol_l4_sourced_writes",
	.event = "event=0xaa",
	.desc = "L1I Off-Drawer Same-Column L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_scol_l3_sourced_writes_iv",
	.event = "event=0xab",
	.desc = "L1I Off-Drawer Same-Column L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_scol_l3_sourced_writes",
	.event = "event=0xac",
	.desc = "L1I Off-Drawer Same-Column L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_fcol_l4_sourced_writes",
	.event = "event=0xad",
	.desc = "L1I Off-Drawer Far-Column L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_fcol_l3_sourced_writes_iv",
	.event = "event=0xae",
	.desc = "L1I Off-Drawer Far-Column L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_fcol_l3_sourced_writes",
	.event = "event=0xaf",
	.desc = "L1I Off-Drawer Far-Column L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onnode_mem_sourced_writes",
	.event = "event=0xb0",
	.desc = "L1I On-Node Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Node memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_ondrawer_mem_sourced_writes",
	.event = "event=0xb1",
	.desc = "L1I On-Drawer Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_mem_sourced_writes",
	.event = "event=0xb2",
	.desc = "L1I Off-Drawer Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_mem_sourced_writes",
	.event = "event=0xb3",
	.desc = "L1I On-Chip Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Chip memory",
	.pmu = "cpum_cf",
},
{
	.name = "tx_nc_tabort",
	.event = "event=0xda",
	.desc = "Aborted transactions in non-constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a non-constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tabort_no_special",
	.event = "event=0xdb",
	.desc = "Aborted transactions in constrained TX mode not using special completion logic. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tabort_special",
	.event = "event=0xdc",
	.desc = "Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete",
	.pmu = "cpum_cf",
},
{
	.name = "mt_diag_cycles_one_thr_active",
	.event = "event=0x1c0",
	.desc = "Cycle count with one thread active. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycle count with one thread active",
	.pmu = "cpum_cf",
},
{
	.name = "mt_diag_cycles_two_thr_active",
	.event = "event=0x1c1",
	.desc = "Cycle count with two threads active. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycle count with two threads active",
	.pmu = "cpum_cf",
},
{
	.name = 0,
	.event = 0,
	.desc = 0,
},
};
static const struct pmu_event pme_cf_z14[] = {
{
	.name = "cpu_cycles",
	.event = "event=0",
	.desc = "Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "instructions",
	.event = "event=0x1",
	.desc = "Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_dir_writes",
	.event = "event=0x2",
	.desc = "Level-1 I-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 instruction-cache or unified-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_penalty_cycles",
	.event = "event=0x3",
	.desc = "Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_dir_writes",
	.event = "event=0x4",
	.desc = "Level-1 D-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 data-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_penalty_cycles",
	.event = "event=0x5",
	.desc = "Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 data cache",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_cpu_cycles",
	.event = "event=0x20",
	.desc = "Problem-State Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_instructions",
	.event = "event=0x21",
	.desc = "Problem-State Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU while in the problem state",
	.pmu = "cpum_cf",
},
{
	.desc = "Transaction count",
	.topic = "transaction",
	.metric_expr = "TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL",
	.metric_name = "transaction",
},
{
	.name = "prng_functions",
	.event = "event=0x40",
	.desc = "PRNG Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_cycles",
	.event = "event=0x41",
	.desc = "PRNG Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_functions",
	.event = "event=0x42",
	.desc = "PRNG Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_cycles",
	.event = "event=0x43",
	.desc = "PRNG Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_functions",
	.event = "event=0x44",
	.desc = "SHA Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_cycles",
	.event = "event=0x45",
	.desc = "SHA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_functions",
	.event = "event=0x46",
	.desc = "SHA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_cycles",
	.event = "event=0x47",
	.desc = "SHA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_functions",
	.event = "event=0x48",
	.desc = "DEA Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_cycles",
	.event = "event=0x49",
	.desc = "DEA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_functions",
	.event = "event=0x4a",
	.desc = "DEA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_cycles",
	.event = "event=0x4b",
	.desc = "DEA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_functions",
	.event = "event=0x4c",
	.desc = "AES Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_cycles",
	.event = "event=0x4d",
	.desc = "AES Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_functions",
	.event = "event=0x4e",
	.desc = "AES Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_cycles",
	.event = "event=0x4f",
	.desc = "AES Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_ro_excl_writes",
	.event = "event=0x80",
	.desc = "L1D Read-only Exclusive Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb2_writes",
	.event = "event=0x81",
	.desc = "DTLB2 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the data cache. This is a replacement for what was provided for the DTLB on prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb2_misses",
	.event = "event=0x82",
	.desc = "DTLB2 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TLB2 miss is in progress for a request made by the data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb2_hpage_writes",
	.event = "event=0x83",
	.desc = "DTLB2 One-Megabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page or a Last Host Translation was done",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb2_gpage_writes",
	.event = "event=0x84",
	.desc = "DTLB2 Two-Gigabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry for a two-gigabyte page was written into the Level-2 TLB",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_l2d_sourced_writes",
	.event = "event=0x85",
	.desc = "L1D L2D Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache",
	.pmu = "cpum_cf",
},
{
	.name = "itlb2_writes",
	.event = "event=0x86",
	.desc = "ITLB2 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "itlb2_misses",
	.event = "event=0x87",
	.desc = "ITLB2 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TLB2 miss is in progress for a request made by the instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_l2i_sourced_writes",
	.event = "event=0x88",
	.desc = "L1I L2I Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_pte_writes",
	.event = "event=0x89",
	.desc = "TLB2 PTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry was written into the Page Table Entry array in the Level-2 TLB",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_crste_writes",
	.event = "event=0x8a",
	.desc = "TLB2 CRSTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_engines_busy",
	.event = "event=0x8b",
	.desc = "TLB2 Engines Busy. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "The number of Level-2 TLB translation engines busy in a cycle",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tend",
	.event = "event=0x8c",
	.desc = "Completed TEND instructions in constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TEND instruction has completed in a constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "tx_nc_tend",
	.event = "event=0x8d",
	.desc = "Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TEND instruction has completed in a non-constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "l1c_tlb2_misses",
	.event = "event=0x8f",
	.desc = "L1C TLB2 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Increments by one for any cycle where a level-1 cache or level-2 TLB miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_l3_sourced_writes",
	.event = "event=0x90",
	.desc = "L1D On-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_memory_sourced_writes",
	.event = "event=0x91",
	.desc = "L1D On-Chip Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_l3_sourced_writes_iv",
	.event = "event=0x92",
	.desc = "L1D On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_oncluster_l3_sourced_writes",
	.event = "event=0x93",
	.desc = "L1D On-Cluster L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Cluster Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_oncluster_memory_sourced_writes",
	.event = "event=0x94",
	.desc = "L1D On-Cluster Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_oncluster_l3_sourced_writes_iv",
	.event = "event=0x95",
	.desc = "L1D On-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offcluster_l3_sourced_writes",
	.event = "event=0x96",
	.desc = "L1D Off-Cluster L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offcluster_memory_sourced_writes",
	.event = "event=0x97",
	.desc = "L1D Off-Cluster Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Cluster memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offcluster_l3_sourced_writes_iv",
	.event = "event=0x98",
	.desc = "L1D Off-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_l3_sourced_writes",
	.event = "event=0x99",
	.desc = "L1D Off-Drawer L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_memory_sourced_writes",
	.event = "event=0x9a",
	.desc = "L1D Off-Drawer Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_l3_sourced_writes_iv",
	.event = "event=0x9b",
	.desc = "L1D Off-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_ondrawer_l4_sourced_writes",
	.event = "event=0x9c",
	.desc = "L1D On-Drawer L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_l4_sourced_writes",
	.event = "event=0x9d",
	.desc = "L1D Off-Drawer L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_l3_sourced_writes_ro",
	.event = "event=0x9e",
	.desc = "L1D On-Chip L3 Sourced Writes read-only. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip L3 but a read-only invalidate was done to remove other copies of the cache line",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_l3_sourced_writes",
	.event = "event=0xa2",
	.desc = "L1I On-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_memory_sourced_writes",
	.event = "event=0xa3",
	.desc = "L1I On-Chip Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from On-Chip memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_l3_sourced_writes_iv",
	.event = "event=0xa4",
	.desc = "L1I On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_oncluster_l3_sourced_writes",
	.event = "event=0xa5",
	.desc = "L1I On-Cluster L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_oncluster_memory_sourced_writes",
	.event = "event=0xa6",
	.desc = "L1I On-Cluster Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_oncluster_l3_sourced_writes_iv",
	.event = "event=0xa7",
	.desc = "L1I On-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Cluster Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offcluster_l3_sourced_writes",
	.event = "event=0xa8",
	.desc = "L1I Off-Cluster L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offcluster_memory_sourced_writes",
	.event = "event=0xa9",
	.desc = "L1I Off-Cluster Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Cluster memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offcluster_l3_sourced_writes_iv",
	.event = "event=0xaa",
	.desc = "L1I Off-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_l3_sourced_writes",
	.event = "event=0xab",
	.desc = "L1I Off-Drawer L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_memory_sourced_writes",
	.event = "event=0xac",
	.desc = "L1I Off-Drawer Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_l3_sourced_writes_iv",
	.event = "event=0xad",
	.desc = "L1I Off-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_ondrawer_l4_sourced_writes",
	.event = "event=0xae",
	.desc = "L1I On-Drawer L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_l4_sourced_writes",
	.event = "event=0xaf",
	.desc = "L1I Off-Drawer L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "bcd_dfp_execution_slots",
	.event = "event=0xe0",
	.desc = "BCD DFP Execution Slots. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT",
	.pmu = "cpum_cf",
},
{
	.name = "vx_bcd_execution_slots",
	.event = "event=0xe1",
	.desc = "VX BCD Execution Slots. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMPVMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOPVCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVDVCVDG",
	.pmu = "cpum_cf",
},
{
	.name = "decimal_instructions",
	.event = "event=0xe2",
	.desc = "Decimal Instructions. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Decimal instructions dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP",
	.pmu = "cpum_cf",
},
{
	.name = "last_host_translations",
	.event = "event=0xe8",
	.desc = "Last host translation done. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Last Host Translation done",
	.pmu = "cpum_cf",
},
{
	.name = "tx_nc_tabort",
	.event = "event=0xf3",
	.desc = "Aborted transactions in non-constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a non-constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tabort_no_special",
	.event = "event=0xf4",
	.desc = "Aborted transactions in constrained TX mode not using special completion logic. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tabort_special",
	.event = "event=0xf5",
	.desc = "Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete",
	.pmu = "cpum_cf",
},
{
	.name = "mt_diag_cycles_one_thr_active",
	.event = "event=0x1c0",
	.desc = "Cycle count with one thread active. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycle count with one thread active",
	.pmu = "cpum_cf",
},
{
	.name = "mt_diag_cycles_two_thr_active",
	.event = "event=0x1c1",
	.desc = "Cycle count with two threads active. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycle count with two threads active",
	.pmu = "cpum_cf",
},
{
	.name = 0,
	.event = 0,
	.desc = 0,
},
};
static const struct pmu_event pme_cf_z15[] = {
{
	.name = "prng_functions",
	.event = "event=0x40",
	.desc = "PRNG Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_cycles",
	.event = "event=0x41",
	.desc = "PRNG Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_functions",
	.event = "event=0x42",
	.desc = "PRNG Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_cycles",
	.event = "event=0x43",
	.desc = "PRNG Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_functions",
	.event = "event=0x44",
	.desc = "SHA Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_cycles",
	.event = "event=0x45",
	.desc = "SHA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_functions",
	.event = "event=0x46",
	.desc = "SHA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_cycles",
	.event = "event=0x47",
	.desc = "SHA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_functions",
	.event = "event=0x48",
	.desc = "DEA Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_cycles",
	.event = "event=0x49",
	.desc = "DEA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_functions",
	.event = "event=0x4a",
	.desc = "DEA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_cycles",
	.event = "event=0x4b",
	.desc = "DEA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_functions",
	.event = "event=0x4c",
	.desc = "AES Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_cycles",
	.event = "event=0x4d",
	.desc = "AES Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_functions",
	.event = "event=0x4e",
	.desc = "AES Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_cycles",
	.event = "event=0x4f",
	.desc = "AES Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "ecc_function_count",
	.event = "event=0x50",
	.desc = "ECC Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the elliptic-curve cryptography (ECC) functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "ecc_cycles_count",
	.event = "event=0x51",
	.desc = "ECC Cycles Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles when the ECC coprocessor is busy performing the elliptic-curve cryptography (ECC) functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "ecc_blocked_function_count",
	.event = "event=0x52",
	.desc = "Ecc Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the elliptic-curve cryptography (ECC) functions that are issued by the CPU and are blocked because the ECC coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "ecc_blocked_cycles_count",
	.event = "event=0x53",
	.desc = "ECC Blocked Cycles Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the elliptic-curve cryptography (ECC) functions issued by the CPU because the ECC coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "cpu_cycles",
	.event = "event=0",
	.desc = "Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "instructions",
	.event = "event=0x1",
	.desc = "Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_dir_writes",
	.event = "event=0x2",
	.desc = "Level-1 I-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 instruction-cache or unified-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_penalty_cycles",
	.event = "event=0x3",
	.desc = "Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_dir_writes",
	.event = "event=0x4",
	.desc = "Level-1 D-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 data-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_penalty_cycles",
	.event = "event=0x5",
	.desc = "Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 data cache",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_cpu_cycles",
	.event = "event=0x20",
	.desc = "Problem-State Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_instructions",
	.event = "event=0x21",
	.desc = "Problem-State Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU while in the problem state",
	.pmu = "cpum_cf",
},
{
	.desc = "Transaction count",
	.topic = "transaction",
	.metric_expr = "TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL",
	.metric_name = "transaction",
},
{
	.name = "l1d_ro_excl_writes",
	.event = "event=0x80",
	.desc = "L1D Read-only Exclusive Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb2_writes",
	.event = "event=0x81",
	.desc = "DTLB2 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the data cache. This is a replacement for what was provided for the DTLB on prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb2_misses",
	.event = "event=0x82",
	.desc = "DTLB2 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TLB2 miss is in progress for a request made by the data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb2_hpage_writes",
	.event = "event=0x83",
	.desc = "DTLB2 One-Megabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb2_gpage_writes",
	.event = "event=0x84",
	.desc = "DTLB2 Two-Gigabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry for a two-gigabyte page was written into the Level-2 TLB",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_l2d_sourced_writes",
	.event = "event=0x85",
	.desc = "L1D L2D Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache",
	.pmu = "cpum_cf",
},
{
	.name = "itlb2_writes",
	.event = "event=0x86",
	.desc = "ITLB2 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "itlb2_misses",
	.event = "event=0x87",
	.desc = "ITLB2 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TLB2 miss is in progress for a request made by the instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_l2i_sourced_writes",
	.event = "event=0x88",
	.desc = "L1I L2I Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_pte_writes",
	.event = "event=0x89",
	.desc = "TLB2 PTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry was written into the Page Table Entry array in the Level-2 TLB",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_crste_writes",
	.event = "event=0x8a",
	.desc = "TLB2 CRSTE Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_engines_busy",
	.event = "event=0x8b",
	.desc = "TLB2 Engines Busy. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "The number of Level-2 TLB translation engines busy in a cycle",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tend",
	.event = "event=0x8c",
	.desc = "Completed TEND instructions in constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TEND instruction has completed in a constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "tx_nc_tend",
	.event = "event=0x8d",
	.desc = "Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TEND instruction has completed in a non-constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "l1c_tlb2_misses",
	.event = "event=0x8f",
	.desc = "L1C TLB2 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Increments by one for any cycle where a level-1 cache or level-2 TLB miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_l3_sourced_writes",
	.event = "event=0x90",
	.desc = "L1D On-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_memory_sourced_writes",
	.event = "event=0x91",
	.desc = "L1D On-Chip Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_l3_sourced_writes_iv",
	.event = "event=0x92",
	.desc = "L1D On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_oncluster_l3_sourced_writes",
	.event = "event=0x93",
	.desc = "L1D On-Cluster L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Cluster Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_oncluster_memory_sourced_writes",
	.event = "event=0x94",
	.desc = "L1D On-Cluster Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_oncluster_l3_sourced_writes_iv",
	.event = "event=0x95",
	.desc = "L1D On-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offcluster_l3_sourced_writes",
	.event = "event=0x96",
	.desc = "L1D Off-Cluster L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offcluster_memory_sourced_writes",
	.event = "event=0x97",
	.desc = "L1D Off-Cluster Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Cluster memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offcluster_l3_sourced_writes_iv",
	.event = "event=0x98",
	.desc = "L1D Off-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_l3_sourced_writes",
	.event = "event=0x99",
	.desc = "L1D Off-Drawer L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_memory_sourced_writes",
	.event = "event=0x9a",
	.desc = "L1D Off-Drawer Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_l3_sourced_writes_iv",
	.event = "event=0x9b",
	.desc = "L1D Off-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_ondrawer_l4_sourced_writes",
	.event = "event=0x9c",
	.desc = "L1D On-Drawer L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_offdrawer_l4_sourced_writes",
	.event = "event=0x9d",
	.desc = "L1D Off-Drawer L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_onchip_l3_sourced_writes_ro",
	.event = "event=0x9e",
	.desc = "L1D On-Chip L3 Sourced Writes read-only. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip L3 but a read-only invalidate was done to remove other copies of the cache line",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_l3_sourced_writes",
	.event = "event=0xa2",
	.desc = "L1I On-Chip L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_memory_sourced_writes",
	.event = "event=0xa3",
	.desc = "L1I On-Chip Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from On-Chip memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_onchip_l3_sourced_writes_iv",
	.event = "event=0xa4",
	.desc = "L1I On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_oncluster_l3_sourced_writes",
	.event = "event=0xa5",
	.desc = "L1I On-Cluster L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_oncluster_memory_sourced_writes",
	.event = "event=0xa6",
	.desc = "L1I On-Cluster Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_oncluster_l3_sourced_writes_iv",
	.event = "event=0xa7",
	.desc = "L1I On-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Cluster Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offcluster_l3_sourced_writes",
	.event = "event=0xa8",
	.desc = "L1I Off-Cluster L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offcluster_memory_sourced_writes",
	.event = "event=0xa9",
	.desc = "L1I Off-Cluster Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Cluster memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offcluster_l3_sourced_writes_iv",
	.event = "event=0xaa",
	.desc = "L1I Off-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_l3_sourced_writes",
	.event = "event=0xab",
	.desc = "L1I Off-Drawer L3 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_memory_sourced_writes",
	.event = "event=0xac",
	.desc = "L1I Off-Drawer Memory Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_l3_sourced_writes_iv",
	.event = "event=0xad",
	.desc = "L1I Off-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_ondrawer_l4_sourced_writes",
	.event = "event=0xae",
	.desc = "L1I On-Drawer L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_offdrawer_l4_sourced_writes",
	.event = "event=0xaf",
	.desc = "L1I Off-Drawer L4 Sourced Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache",
	.pmu = "cpum_cf",
},
{
	.name = "bcd_dfp_execution_slots",
	.event = "event=0xe0",
	.desc = "BCD DFP Execution Slots. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT",
	.pmu = "cpum_cf",
},
{
	.name = "vx_bcd_execution_slots",
	.event = "event=0xe1",
	.desc = "VX BCD Execution Slots. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMPVMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOPVCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVDVCVDG",
	.pmu = "cpum_cf",
},
{
	.name = "decimal_instructions",
	.event = "event=0xe2",
	.desc = "Decimal Instructions. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Decimal instructions dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP",
	.pmu = "cpum_cf",
},
{
	.name = "last_host_translations",
	.event = "event=0xe8",
	.desc = "Last host translation done. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Last Host Translation done",
	.pmu = "cpum_cf",
},
{
	.name = "tx_nc_tabort",
	.event = "event=0xf3",
	.desc = "Aborted transactions in non-constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a non-constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tabort_no_special",
	.event = "event=0xf4",
	.desc = "Aborted transactions in constrained TX mode not using special completion logic. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tabort_special",
	.event = "event=0xf5",
	.desc = "Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete",
	.pmu = "cpum_cf",
},
{
	.name = "dflt_access",
	.event = "event=0xf7",
	.desc = "Cycles CPU spent obtaining access to Deflate unit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycles CPU spent obtaining access to Deflate unit",
	.pmu = "cpum_cf",
},
{
	.name = "dflt_cycles",
	.event = "event=0xfc",
	.desc = "Cycles CPU is using Deflate unit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycles CPU is using Deflate unit",
	.pmu = "cpum_cf",
},
{
	.name = "dflt_cc",
	.event = "event=0x108",
	.desc = "Increments DEFLATE CONVERSION CALL. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Increments by one for every DEFLATE CONVERSION CALL instruction executed",
	.pmu = "cpum_cf",
},
{
	.name = "dflt_ccfinish",
	.event = "event=0x109",
	.desc = "Increments completed DEFLATE CONVERSION CALL. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = " Increments by one for every DEFLATE CONVERSION CALL instruction executed that ended in Condition Codes 0, 1 or 2 complete",
	.pmu = "cpum_cf",
},
{
	.name = "mt_diag_cycles_one_thr_active",
	.event = "event=0x1c0",
	.desc = "Cycle count with one thread active. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycle count with one thread active",
	.pmu = "cpum_cf",
},
{
	.name = "mt_diag_cycles_two_thr_active",
	.event = "event=0x1c1",
	.desc = "Cycle count with two threads active. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycle count with two threads active",
	.pmu = "cpum_cf",
},
{
	.name = 0,
	.event = 0,
	.desc = 0,
},
};
static const struct pmu_event pme_cf_z16[] = {
{
	.name = "prng_functions",
	.event = "event=0x40",
	.desc = "PRNG Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_cycles",
	.event = "event=0x41",
	.desc = "PRNG Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_functions",
	.event = "event=0x42",
	.desc = "PRNG Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "prng_blocked_cycles",
	.event = "event=0x43",
	.desc = "PRNG Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_functions",
	.event = "event=0x44",
	.desc = "SHA Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_cycles",
	.event = "event=0x45",
	.desc = "SHA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_functions",
	.event = "event=0x46",
	.desc = "SHA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "sha_blocked_cycles",
	.event = "event=0x47",
	.desc = "SHA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_functions",
	.event = "event=0x48",
	.desc = "DEA Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_cycles",
	.event = "event=0x49",
	.desc = "DEA Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_functions",
	.event = "event=0x4a",
	.desc = "DEA Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "dea_blocked_cycles",
	.event = "event=0x4b",
	.desc = "DEA Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_functions",
	.event = "event=0x4c",
	.desc = "AES Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_cycles",
	.event = "event=0x4d",
	.desc = "AES Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_functions",
	.event = "event=0x4e",
	.desc = "AES Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "aes_blocked_cycles",
	.event = "event=0x4f",
	.desc = "AES Blocked Cycle Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "ecc_function_count",
	.event = "event=0x50",
	.desc = "ECC Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the elliptic-curve cryptography (ECC) functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "ecc_cycles_count",
	.event = "event=0x51",
	.desc = "ECC Cycles Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles when the ECC coprocessor is busy performing the elliptic-curve cryptography (ECC) functions issued by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "ecc_blocked_function_count",
	.event = "event=0x52",
	.desc = "Ecc Blocked Function Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of the elliptic-curve cryptography (ECC) functions that are issued by the CPU and are blocked because the ECC coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "ecc_blocked_cycles_count",
	.event = "event=0x53",
	.desc = "ECC Blocked Cycles Count. Unit: cpum_cf ",
	.topic = "crypto6",
	.long_desc = "This counter counts the total number of CPU cycles blocked for the elliptic-curve cryptography (ECC) functions issued by the CPU because the ECC coprocessor is busy performing a function issued by another CPU",
	.pmu = "cpum_cf",
},
{
	.name = "cpu_cycles",
	.event = "event=0",
	.desc = "Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "instructions",
	.event = "event=0x1",
	.desc = "Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_dir_writes",
	.event = "event=0x2",
	.desc = "Level-1 I-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 instruction-cache or unified-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1i_penalty_cycles",
	.event = "event=0x3",
	.desc = "Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_dir_writes",
	.event = "event=0x4",
	.desc = "Level-1 D-Cache Directory Write Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of level-1 data-cache directory writes",
	.pmu = "cpum_cf",
},
{
	.name = "l1d_penalty_cycles",
	.event = "event=0x5",
	.desc = "Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of cache penalty cycles for level-1 data cache",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_cpu_cycles",
	.event = "event=0x20",
	.desc = "Problem-State Cycle Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state",
	.pmu = "cpum_cf",
},
{
	.name = "problem_state_instructions",
	.event = "event=0x21",
	.desc = "Problem-State Instruction Count. Unit: cpum_cf ",
	.topic = "basic",
	.long_desc = "This counter counts the total number of instructions executed by the CPU while in the problem state",
	.pmu = "cpum_cf",
},
{
	.desc = "Transaction count",
	.topic = "transaction",
	.metric_expr = "TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL",
	.metric_name = "transaction",
},
{
	.name = "l1d_ro_excl_writes",
	.event = "event=0x80",
	.desc = "L1D Read-only Exclusive Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb2_writes",
	.event = "event=0x81",
	.desc = "DTLB2 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the Level-1 Data cache. This is a replacement for what was provided for the DTLB on z13 and prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb2_misses",
	.event = "event=0x82",
	.desc = "DTLB2 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TLB2 miss is in progress for a request made by the Level-1 Data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on z13 and prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "crste_1mb_writes",
	.event = "event=0x83",
	.desc = "One Megabyte CRSTE writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page",
	.pmu = "cpum_cf",
},
{
	.name = "dtlb2_gpage_writes",
	.event = "event=0x84",
	.desc = "DTLB2 Two-Gigabyte Page Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry for a two-gigabyte page was written into the Level-2 TLB",
	.pmu = "cpum_cf",
},
{
	.name = "itlb2_writes",
	.event = "event=0x86",
	.desc = "ITLB2 Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on z13 and prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "itlb2_misses",
	.event = "event=0x87",
	.desc = "ITLB2 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TLB2 miss is in progress for a request made by the Level-1 Instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on z13 and prior machines",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_pte_writes",
	.event = "event=0x89",
	.desc = "TLB2 Page Table Entry Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A translation entry was written into the Page Table Entry array in the Level-2 TLB",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_crste_writes",
	.event = "event=0x8a",
	.desc = "TLB2 Combined Region and Segment Entry Writes. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB",
	.pmu = "cpum_cf",
},
{
	.name = "tlb2_engines_busy",
	.event = "event=0x8b",
	.desc = "TLB2 Engines Busy. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "The number of Level-2 TLB translation engines busy in a cycle",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tend",
	.event = "event=0x8c",
	.desc = "Completed TEND instructions in constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TEND instruction has completed in a constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "tx_nc_tend",
	.event = "event=0x8d",
	.desc = "Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A TEND instruction has completed in a non-constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "l1c_tlb2_misses",
	.event = "event=0x8f",
	.desc = "L1C TLB2 Misses. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Increments by one for any cycle where a level-1 cache or level-2 TLB miss is in progress",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_req",
	.event = "event=0x91",
	.desc = "Directory Write Level 1 Data Cache from Cache. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_req_iv",
	.event = "event=0x92",
	.desc = "Directory Write Level 1 Data Cache from Cache with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_req_chip_hit",
	.event = "event=0x93",
	.desc = "Directory Write Level 1 Data Cache from Cache with Chip HP Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache after using chip level horizontal persistence, Chip-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_req_drawer_hit",
	.event = "event=0x94",
	.desc = "Directory Write Level 1 Data Cache from Cache with Drawer HP Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache after using drawer level horizontal persistence, Drawer-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_on_chip",
	.event = "event=0x95",
	.desc = "Directory Write Level 1 Data Cache from On-Chip Cache. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_on_chip_iv",
	.event = "event=0x96",
	.desc = "Directory Write Level 1 Data Cache from On-Chip Cache with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_on_chip_chip_hit",
	.event = "event=0x97",
	.desc = "Directory Write Level 1 Data Cache from On-Chip Cache with Chip HP Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache after using chip level horizontal persistence, Chip-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_on_chip_drawer_hit",
	.event = "event=0x98",
	.desc = "Directory Write Level 1 Data Cache from On-Chip Cache with Drawer HP Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache using drawer level horizontal persistence, Drawer-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_on_module",
	.event = "event=0x99",
	.desc = "Directory Write Level 1 Data Cache from On-Module Cache. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Module Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_on_drawer",
	.event = "event=0x9a",
	.desc = "Directory Write Level 1 Data Cache from On-Drawer Cache. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_off_drawer",
	.event = "event=0x9b",
	.desc = "Directory Write Level 1 Data Cache from Off-Drawer Cache. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_on_chip_memory",
	.event = "event=0x9c",
	.desc = "Directory Write Level 1 Data Cache from On-Chip Memory. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_on_module_memory",
	.event = "event=0x9d",
	.desc = "Directory Write Level 1 Data Cache from On-Module Memory. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Module memory",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_on_drawer_memory",
	.event = "event=0x9e",
	.desc = "Directory Write Level 1 Data Cache from On-Drawer Memory. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "dcw_off_drawer_memory",
	.event = "event=0x9f",
	.desc = "Directory Write Level 1 Data Cache from Off-Drawer Memory. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "idcw_on_module_iv",
	.event = "event=0xa0",
	.desc = "Directory Write Level 1 Instruction and Data Cache from On-Module Memory Cache with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "idcw_on_module_chip_hit",
	.event = "event=0xa1",
	.desc = "Directory Write Level 1 Instruction and Data Cache from On-Module Memory Cache with Chip Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache using chip horizontal persistence, Chip-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "idcw_on_module_drawer_hit",
	.event = "event=0xa2",
	.desc = "Directory Write Level 1 Instruction and Data Cache from On-Module Memory Cache with Drawer Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache using drawer level horizontal persistence, Drawer-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "idcw_on_drawer_iv",
	.event = "event=0xa3",
	.desc = "Directory Write Level 1 Instruction and Data Cache from On-Drawer Cache with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "idcw_on_drawer_chip_hit",
	.event = "event=0xa4",
	.desc = "Directory Write Level 1 Instruction and Data Cache from On-Drawer Cache with Chip Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache using chip level horizontal persistence, Chip-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "idcw_on_drawer_drawer_hit",
	.event = "event=0xa5",
	.desc = "Directory Write Level 1 Instruction and Data Cache from On-Drawer Cache with Drawer Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache using drawer level horizontal persistence, Drawer-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "idcw_off_drawer_iv",
	.event = "event=0xa6",
	.desc = "Directory Write Level 1 Instruction and Data Cache from Off-Drawer Cache with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "idcw_off_drawer_chip_hit",
	.event = "event=0xa7",
	.desc = "Directory Write Level 1 Instruction and Data Cache from Off-Drawer Cache with Chip Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache using chip level horizontal persistence, Chip-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "idcw_off_drawer_drawer_hit",
	.event = "event=0xa8",
	.desc = "Directory Write Level 1 Instruction and Data Cache from Off-Drawer Cache with Drawer Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache using drawer level horizontal persistence, Drawer-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "icw_req",
	.event = "event=0xa9",
	.desc = "Directory Write Level 1 Instruction Cache from Cache. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced the requestors Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "icw_req_iv",
	.event = "event=0xaa",
	.desc = "Directory Write Level 1 Instruction Cache from Cache with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "icw_req_chip_hit",
	.event = "event=0xab",
	.desc = "Directory Write Level 1 Instruction Cache from Cache with Chip HP Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache using chip level horizontal persistence, Chip-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "icw_req_drawer_hit",
	.event = "event=0xac",
	.desc = "Directory Write Level 1 Instruction Cache from Cache with Drawer HP Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestor’s Level-2 cache using drawer level horizontal persistence, Drawer-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "icw_on_chip",
	.event = "event=0xad",
	.desc = "Directory Write Level 1 Instruction Cache from On-Chip Cache. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "icw_on_chip_iv",
	.event = "event=0xae",
	.desc = "Directory Write Level 1 Instruction Cache from On-Chip Cache with Intervention. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an On-Chip Level-2 cache with intervention",
	.pmu = "cpum_cf",
},
{
	.name = "icw_on_chip_chip_hit",
	.event = "event=0xaf",
	.desc = "Directory Write Level 1 Instruction Cache from On-Chip Cache with Chip HP Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-2 cache using chip level horizontal persistence, Chip-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "icw_on_chip_drawer_hit",
	.event = "event=0xb0",
	.desc = "Directory Write Level 1 Instruction Cache from On-Chip Cache with Drawer HP Hit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip level 2 cache using drawer level horizontal persistence, Drawer-HP hit",
	.pmu = "cpum_cf",
},
{
	.name = "icw_on_module",
	.event = "event=0xb1",
	.desc = "Directory Write Level 1 Instruction Cache from On-Module Cache. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "icw_on_drawer",
	.event = "event=0xb2",
	.desc = "Directory Write Level 1 Instruction Cache from On-Drawer Cache. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an On-Drawer Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "icw_off_drawer",
	.event = "event=0xb3",
	.desc = "Directory Write Level 1 Instruction Cache from Off-Drawer Cache. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an Off-Drawer Level-2 cache",
	.pmu = "cpum_cf",
},
{
	.name = "icw_on_chip_memory",
	.event = "event=0xb4",
	.desc = "Directory Write Level 1 Instruction Cache from On-Chip Memory. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Chip memory",
	.pmu = "cpum_cf",
},
{
	.name = "icw_on_module_memory",
	.event = "event=0xb5",
	.desc = "Directory Write Level 1 Instruction Cache from On-Module Memory. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Module memory",
	.pmu = "cpum_cf",
},
{
	.name = "icw_on_drawer_memory",
	.event = "event=0xb6",
	.desc = "Directory Write Level 1 Instruction Cache from On-Drawer Memory. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "icw_off_drawer_memory",
	.event = "event=0xb7",
	.desc = "Directory Write Level 1 Instruction Cache from Off-Drawer Memory. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory",
	.pmu = "cpum_cf",
},
{
	.name = "bcd_dfp_execution_slots",
	.event = "event=0xe0",
	.desc = "Binary Coded Decimal to Decimal Floating Point conversions. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT",
	.pmu = "cpum_cf",
},
{
	.name = "vx_bcd_execution_slots",
	.event = "event=0xe1",
	.desc = "Count finished vector arithmetic Binary Coded Decimal instructions. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMP, VMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOP, VCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVD, VCVDG",
	.pmu = "cpum_cf",
},
{
	.name = "decimal_instructions",
	.event = "event=0xe2",
	.desc = "Decimal instruction dispatched. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Decimal instruction dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP",
	.pmu = "cpum_cf",
},
{
	.name = "last_host_translations",
	.event = "event=0xe8",
	.desc = "Last host translation done. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Last Host Translation done",
	.pmu = "cpum_cf",
},
{
	.name = "tx_nc_tabort",
	.event = "event=0xf4",
	.desc = "Aborted transactions in unconstrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a non-constrained transactional-execution mode",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tabort_no_special",
	.event = "event=0xf5",
	.desc = "Aborted transactions in constrained TX mode. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete",
	.pmu = "cpum_cf",
},
{
	.name = "tx_c_tabort_special",
	.event = "event=0xf6",
	.desc = "Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete",
	.pmu = "cpum_cf",
},
{
	.name = "dflt_access",
	.event = "event=0xf8",
	.desc = "Cycles CPU spent obtaining access to Deflate unit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycles CPU spent obtaining access to Deflate unit",
	.pmu = "cpum_cf",
},
{
	.name = "dflt_cycles",
	.event = "event=0xfd",
	.desc = "Cycles CPU is using Deflate unit. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycles CPU is using Deflate unit",
	.pmu = "cpum_cf",
},
{
	.name = "sortl",
	.event = "event=0x100",
	.desc = "Count SORTL instructions. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Increments by one for every SORT LISTS instruction executed",
	.pmu = "cpum_cf",
},
{
	.name = "dflt_cc",
	.event = "event=0x109",
	.desc = "Increments DEFLATE CONVERSION CALL. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Increments by one for every DEFLATE CONVERSION CALL instruction executed",
	.pmu = "cpum_cf",
},
{
	.name = "dflt_ccfinish",
	.event = "event=0x10a",
	.desc = "Increments completed DEFLATE CONVERSION CALL. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Increments by one for every DEFLATE CONVERSION CALL instruction executed that ended in Condition Codes 0, 1 or 2",
	.pmu = "cpum_cf",
},
{
	.name = "nnpa_invocations",
	.event = "event=0x10b",
	.desc = "NNPA Total invocations. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Increments by one for every Neural Network Processing Assist instruction executed",
	.pmu = "cpum_cf",
},
{
	.name = "nnpa_completions",
	.event = "event=0x10c",
	.desc = "NNPA Total completions. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Increments by one for every Neural Network Processing Assist instruction executed that ended in Condition Codes 0, 1 or 2",
	.pmu = "cpum_cf",
},
{
	.name = "nnpa_wait_lock",
	.event = "event=0x10d",
	.desc = "Cycles spent obtaining NNPA lock. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycles CPU spent obtaining access to IBM Z Integrated Accelerator for AI",
	.pmu = "cpum_cf",
},
{
	.name = "nnpa_hold_lock",
	.event = "event=0x10e",
	.desc = "Cycles spent holding NNPA lock. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycles CPU is using IBM Z Integrated Accelerator for AI",
	.pmu = "cpum_cf",
},
{
	.name = "mt_diag_cycles_one_thr_active",
	.event = "event=0x1c0",
	.desc = "Cycle count with one thread active. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycle count with one thread active",
	.pmu = "cpum_cf",
},
{
	.name = "mt_diag_cycles_two_thr_active",
	.event = "event=0x1c1",
	.desc = "Cycle count with two threads active. Unit: cpum_cf ",
	.topic = "extended",
	.long_desc = "Cycle count with two threads active",
	.pmu = "cpum_cf",
},
{
	.name = 0,
	.event = 0,
	.desc = 0,
},
};
static const struct pmu_event pme_test_soc_cpu[] = {
{
	.name = "bp_l1_btb_correct",
	.event = "event=0x8a",
	.desc = "L1 BTB Correction",
	.topic = "branch",
},
{
	.name = "bp_l2_btb_correct",
	.event = "event=0x8b",
	.desc = "L2 BTB Correction",
	.topic = "branch",
},
{
	.name = "segment_reg_loads.any",
	.event = "event=0x6,period=200000,umask=0x80",
	.desc = "Number of segment register loads",
	.topic = "other",
},
{
	.name = "dispatch_blocked.any",
	.event = "event=0x9,period=200000,umask=0x20",
	.desc = "Memory cluster signals to block micro-op dispatch for any reason",
	.topic = "other",
},
{
	.name = "eist_trans",
	.event = "event=0x3a,period=200000,umask=0x0",
	.desc = "Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions",
	.topic = "other",
},
{
	.name = "uncore_hisi_ddrc.flux_wcmd",
	.event = "event=0x2",
	.desc = "DDRC write commands. Unit: hisi_sccl,ddrc ",
	.topic = "uncore",
	.long_desc = "DDRC write commands",
	.pmu = "hisi_sccl,ddrc",
},
{
	.name = "unc_cbo_xsnp_response.miss_eviction",
	.event = "event=0x22,umask=0x81",
	.desc = "A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox ",
	.topic = "uncore",
	.long_desc = "A cross-core snoop resulted from L3 Eviction which misses in some processor core",
	.pmu = "uncore_cbox",
},
{
	.name = "event-hyphen",
	.event = "event=0xe0,umask=0x00",
	.desc = "UNC_CBO_HYPHEN. Unit: uncore_cbox ",
	.topic = "uncore",
	.long_desc = "UNC_CBO_HYPHEN",
	.pmu = "uncore_cbox",
},
{
	.name = "event-two-hyph",
	.event = "event=0xc0,umask=0x00",
	.desc = "UNC_CBO_TWO_HYPH. Unit: uncore_cbox ",
	.topic = "uncore",
	.long_desc = "UNC_CBO_TWO_HYPH",
	.pmu = "uncore_cbox",
},
{
	.name = "uncore_hisi_l3c.rd_hit_cpipe",
	.event = "event=0x7",
	.desc = "Total read hits. Unit: hisi_sccl,l3c ",
	.topic = "uncore",
	.long_desc = "Total read hits",
	.pmu = "hisi_sccl,l3c",
},
{
	.name = "uncore_imc_free_running.cache_miss",
	.event = "event=0x12",
	.desc = "Total cache misses. Unit: uncore_imc_free_running ",
	.topic = "uncore",
	.long_desc = "Total cache misses",
	.pmu = "uncore_imc_free_running",
},
{
	.name = "uncore_imc.cache_hits",
	.event = "event=0x34",
	.desc = "Total cache hits. Unit: uncore_imc ",
	.topic = "uncore",
	.long_desc = "Total cache hits",
	.pmu = "uncore_imc",
},
{
	.name = "l3_cache_rd",
	.event = "event=0x40",
	.desc = "L3 cache access, read",
	.topic = "cache",
	.long_desc = "Attributable Level 3 cache access, read",
},
{
	.name = 0,
	.event = 0,
	.desc = 0,
},
};
static const struct pmu_event pme_test_soc_sys[] = {
{
	.name = "sys_ddr_pmu.write_cycles",
	.event = "event=0x2b",
	.desc = "ddr write-cycles event. Unit: uncore_sys_ddr_pmu ",
	.compat = "v8",
	.topic = "uncore",
	.pmu = "uncore_sys_ddr_pmu",
},
{
	.name = "sys_ccn_pmu.read_cycles",
	.event = "config=0x2c",
	.desc = "ccn read-cycles event. Unit: uncore_sys_ccn_pmu ",
	.compat = "0x01",
	.topic = "uncore",
	.pmu = "uncore_sys_ccn_pmu",
},
{
	.name = 0,
	.event = 0,
	.desc = 0,
},
};
const struct pmu_events_map pmu_events_map[] = {
{
	.cpuid = "^IBM.209[78].*[13]\\.[1-5].[[:xdigit:]]+$",
	.version = "1",
	.type = "core",
	.table = pme_cf_z10
},
{
	.cpuid = "^IBM.281[78].*[13]\\.[1-5].[[:xdigit:]]+$",
	.version = "1",
	.type = "core",
	.table = pme_cf_z196
},
{
	.cpuid = "^IBM.282[78].*[13]\\.[1-5].[[:xdigit:]]+$",
	.version = "1",
	.type = "core",
	.table = pme_cf_zec12
},
{
	.cpuid = "^IBM.296[45].*[13]\\.[1-5].[[:xdigit:]]+$",
	.version = "1",
	.type = "core",
	.table = pme_cf_z13
},
{
	.cpuid = "^IBM.390[67].*[13]\\.[1-5].[[:xdigit:]]+$",
	.version = "3",
	.type = "core",
	.table = pme_cf_z14
},
{
	.cpuid = "^IBM.856[12].*3\\.6.[[:xdigit:]]+$",
	.version = "3",
	.type = "core",
	.table = pme_cf_z15
},
{
	.cpuid = "^IBM.393[12].*3\\.7.[[:xdigit:]]+$",
	.version = "3",
	.type = "core",
	.table = pme_cf_z16
},
{
	.cpuid = "testcpu",
	.version = "v1",
	.type = "core",
	.table = pme_test_soc_cpu,
},
{
	.cpuid = 0,
	.version = 0,
	.type = 0,
	.table = 0,
},
};

const struct pmu_sys_events pmu_sys_event_tables[] = {
	{
		.table = pme_test_soc_sys,
		.name = "pme_test_soc_sys",
	},
	{
		.table = 0
	},
};
